@@ -1,6 +1,6 @@
 """Placeless Translation Service for providing I18n to file-based code.
 
-$Id: PlacelessTranslationService.py 23420 2006-05-14 22:44:37Z hannosch $
+$Id: PlacelessTranslationService.py 31165 2006-09-29 00:42:03Z hannosch $
 """
 
 import sys, os, re, fnmatch
@@ -35,7 +35,7 @@ _marker = []
 
 # Setting up some regular expressions for finding interpolation variables in
 # the text.
-NAME_RE = r"[a-zA-Z][a-zA-Z0-9_]*"
+NAME_RE = r"[a-zA-Z][-a-zA-Z0-9_]*"
 _interp_regex = re.compile(r'(?<!\$)(\$(?:%(n)s|{%(n)s}))' %({'n': NAME_RE}))
 _get_var_regex = re.compile(r'%(n)s' %({'n': NAME_RE}))
 
@@ -103,12 +103,12 @@ class PTSWrapper(Base):
         if not service: return default
         return service.utranslate(domain, msgid, mapping, context, target_language, default)
 
-    security.declarePublic(view, 'getLanguageName')
+    security.declareProtected(view, 'getLanguageName')
     def getLanguageName(self, code, context):
         service = self.load(context)
         return service.getLanguageName(code)
 
-    security.declarePublic(view, 'getLanguages')
+    security.declareProtected(view, 'getLanguages')
     def getLanguages(self, context, domain=None):
         service = self.load(context)
         return service.getLanguages(domain)
@@ -146,7 +146,7 @@ class PlacelessTranslationService(Folder):
     # -3 for alpha, -2 for beta, -1 for release candidate
     # use an internal of > 99 to recreate the PTS at every startup
     # (development mode)
-    _class_version = (1, 3, 1, 0)
+    _class_version = (1, 3, 3, 0)
     all_meta_types = ()
 
     manage_options = Folder.manage_options + (
@@ -285,7 +285,7 @@ class PlacelessTranslationService(Folder):
             raise
         except:
             exc=sys.exc_info()
-            log('Message Catalog has errors', logging.WARNING, name, exc)
+            log('Message Catalog has errors', logging.WARNING, pofile, exc)
             self.addCatalog(BrokenMessageCatalog(id, pofile, exc))
 
     def _load_i18n_dir(self, basepath):
@@ -580,6 +580,14 @@ class PlacelessTranslationService(Folder):
         if not mapping:
             return text
 
+        if not isinstance(text, unicode):
+            try:
+                text = unicode(text, 'utf-8')
+            except UnicodeDecodeError:
+                pass
+                # XXX Should log a warning in the future
+                # log('Problem decoding encoded string: %s' % text, logging.ERROR)
+
         # Find all the spots we want to substitute
         to_replace = _interp_regex.findall(text)
 
@@ -590,10 +598,14 @@ class PlacelessTranslationService(Folder):
             if value is None:
                 value = string
             try:
-                if isinstance(text, unicode):
-                    value = u'%s' % value
-                else:
+                if not isinstance(value, basestring):
                     value = str(value)
+                if isinstance(text, unicode):
+                    try:
+                        value = u'%s' % value
+                    except UnicodeDecodeError, msg:
+                        # XXX Should log a warning in the future
+                        value = unicode(value, 'utf-8')
                 text = text.replace(string, value)
             except UnicodeDecodeError, msg:
                 log('Decoding problem in: %s %s' % (text, msg), logging.WARNING)
